#############################################################################

### CLIMATE IMMOBILITY TRAPS: A HOUSEHOLD-LEVEL TEST ###    

#############################################################################     

################################################################################################################################################
################################################################################################################################################

##
##  This script: Causal Machine Learning Analysis (Main) ##   
##                                                            
##  Authors: Marco Letta (Sapienza University of Rome); Pierluigi Montalbano (Sapienza University of Rome); Adriana Paolantonio (World Bank)  ##
#
##  Date: October 2023 #
##                                                            

################################################################################################################################################
################################################################################################################################################

#==========================================================================================================================================================================#
# This R script carries out the placebo test reported in the paper using the causal forest algorithm developed by Wager & Athey (2018) and Athey et al. (2019)
#==========================================================================================================================================================================#

#======================================================================================================#############
# Final outputs: 1) Figure A1; 2) "results_placebo.csv" (Placebo CATE dataset to be analyzed in Stata)
#======================================================================================================#############

# install R packages if needed
# install.packages("randomForest")
# install.packages("grf)
# install.packages("devtools")
# devtools::install_github("grf-labs/sufrep")
# load the required packages
library(randomForest)
library(grf)
library(devtools)
library(sufrep)

# load the dataset
path <- "C:/Users/wb614536/OneDrive - WBG/Documents/Reproducibility/20231030-climate-immobility/files submitted/Reproducibility package/"

dataset <- read.csv(paste(path,"Datasets/dataset.csv", sep = "")) # please change working directory to load this file
names(dataset)
# Causal forest analysis (Wager & Athey, 2018; Athey et al., 2019) 
set.seed(30102023) # set seed for replication; seed is today's date
# 1) Orthogonalization
dataset$hhid <- as.factor(dataset$hhid)
dataset$spei_placebo <- (dataset$spei_placebo)*(-1) # invert sign of the placebo SPEI variable to improve interpretability
dataset$l1spei_placebo <- (dataset$l1spei_placebo)*(-1) # invert sign of the lagged placebo SPEI variable to improve interpretability
encoder <- make_encoder(dataset[, c(8, 9, 21, 23, 25, 27, 29, 30, 31)], dataset$hhid, method="means") # to incorporate household fixed effects, we use the sufrep package implementing the method developed in Johannemann et al. (2019)
X3 <- encoder(dataset[, c(8, 9, 21, 23, 25, 27, 29, 30, 31)], dataset$hhid)
X3 <- cbind(X3, dataset[, c(3, 34:388)])
Y.forest = regression_forest(X3, dataset$migrated, clusters = dataset$hhid, tune.parameters = "all", num.thread=12)
Y.hat = predict(Y.forest)$predictions
W.forest = regression_forest(X3, dataset$spei_placebo, clusters = dataset$hhid, tune.parameters = "all",  num.thread=12)
W.hat = predict(W.forest)$predictions
# 2) Causal Forest
cf = causal_forest(dataset[, c(13, 15, 17, 19, 33)], dataset$migrated, dataset$spei_placebo,
                   Y.hat = Y.hat,
                   W.hat = W.hat,
                   clusters = dataset$hhid,
                   tune.parameters = "all",
                   num.thread=12)
tau.hat = predict(cf,estimate.variance = TRUE)$predictions
sqrt = predict(cf,estimate.variance = TRUE)$variance.estimates
# multiply*100 to improve interpretability
tau.hat = tau.hat*100
png(paste(path,"Outputs/Figure A1.png", sep = ""))
hist(tau.hat, ylim= c(0,2000), breaks = c(-45,-40, -35, -30, -25, -20, -15, -10, -5, 0, 5, 10, 15, 20, 25, 30, 35, 40, 45, 50, 55, 60, 65), freq=TRUE) # Figure A1
dev.off() # Close the PNG graphics device
# 3) Post-estimation analysis
test_calibration(cf) # heuristics to see if forest worked well and successfully captured heterogeneity of treatment effects
#tree <- get_tree(cf, 1) # get a representative tree out of the forest
#plot(tree)
# get ATE
ATE <- average_treatment_effect(cf, target.sample = "all")
ATE # This is the placebo ATE and its standard error reported in the paper
# export the results
results <- cbind(dataset, tau.hat, sqrt)
write.csv(results,paste(path,"Outputs/results_placebo.csv",sep = ""), row.names = FALSE)
# now move to Stata for the CATE_placebo.do analysis